@@ -1,30 +1,29 @@
 """
 Module implementing the main download client class
 """
+import json
 import logging
-import warnings
 import os
 import sys
-import json
+import warnings
 from concurrent.futures import ThreadPoolExecutor, as_completed
 
 import requests
 from tqdm.auto import tqdm
 
 from ..config import SHConfig
-from ..constants import RequestType, MimeType
+from ..constants import MimeType, RequestType
 from ..decoding import decode_data as decode_data_function
-from ..exceptions import DownloadFailedException, SHRuntimeWarning, HashedNameCollisionException
+from ..exceptions import DownloadFailedException, HashedNameCollisionException, SHRuntimeWarning
 from ..io_utils import read_data, write_data
 from .handlers import fail_user_errors, retry_temporary_errors
 from .request import DownloadRequest
 
-
 LOGGER = logging.getLogger(__name__)
 
 
 class DownloadClient:
-    """ A basic download client object
+    """A basic download client object
 
     It does the following:
 
@@ -33,6 +32,7 @@ class DownloadClient:
     - decodes downloaded data,
     - reads and writes locally stored/cached data
     """
+
     def __init__(self, *, redownload=False, raise_download_errors=True, config=None):
         """
         :param redownload: If `True` the data will always be downloaded again. By default this is set to `False` and
@@ -51,7 +51,7 @@ class DownloadClient:
         self.config = config or SHConfig()
 
     def download(self, download_requests, max_threads=None, decode_data=True, show_progress=False):
-        """ Download one or multiple requests, provided as a request list.
+        """Download one or multiple requests, provided as a request list.
 
         :param download_requests: A list of requests or a single request to be executed.
         :type download_requests: List[DownloadRequest] or DownloadRequest
@@ -91,8 +91,7 @@ class DownloadClient:
         return data_list
 
     def _process_download_future(self, future):
-        """ Unpacks the future and correctly handles exceptions
-        """
+        """Unpacks the future and correctly handles exceptions"""
         try:
             return future.result()
         except DownloadFailedException as download_exception:
@@ -104,15 +103,14 @@ class DownloadClient:
             return None
 
     def _single_download(self, request, decode_data):
-        """ Method for downloading a single request
-        """
+        """Method for downloading a single request"""
         request.raise_if_invalid()
 
         request_path, response_path = request.get_storage_paths()
 
         if not self._is_download_required(request, response_path):
             if request.return_data:
-                LOGGER.debug('Reading locally stored data from %s instead of downloading', response_path)
+                LOGGER.debug("Reading locally stored data from %s instead of downloading", response_path)
                 self._check_cached_request_is_matching(request, request_path)
                 return read_data(response_path, data_format=request.data_type if decode_data else MimeType.RAW)
             return None
@@ -122,11 +120,11 @@ class DownloadClient:
         if request_path and request.save_response and (self.redownload or not os.path.exists(request_path)):
             request_info = request.get_request_params(include_metadata=True)
             write_data(request_path, request_info, data_format=MimeType.JSON)
-            LOGGER.debug('Saved request info to %s', request_path)
+            LOGGER.debug("Saved request info to %s", request_path)
 
         if request.save_response:
             write_data(response_path, response_content, data_format=MimeType.RAW)
-            LOGGER.debug('Saved data to %s', response_path)
+            LOGGER.debug("Saved data to %s", response_path)
 
         if request.return_data:
             if decode_data:
@@ -137,50 +135,55 @@ class DownloadClient:
     @retry_temporary_errors
     @fail_user_errors
     def _execute_download(self, request):
-        """ A default way of executing a single download request
-        """
-        LOGGER.debug('Sending %s request to %s. Hash of sent request is %s',
-                     request.request_type.value, request.url, request.get_hashed_name())
+        """A default way of executing a single download request"""
+        LOGGER.debug(
+            "Sending %s request to %s. Hash of sent request is %s",
+            request.request_type.value,
+            request.url,
+            request.get_hashed_name(),
+        )
 
         response = requests.request(
             request.request_type.value,
             url=request.url,
             json=request.post_values,
             headers=request.headers,
-            timeout=self.config.download_timeout_seconds
+            timeout=self.config.download_timeout_seconds,
         )
 
         response.raise_for_status()
-        LOGGER.debug('Successful %s request to %s', request.request_type.value, request.url)
+        LOGGER.debug("Successful %s request to %s", request.request_type.value, request.url)
 
         return response.content
 
     def _is_download_required(self, request, response_path):
-        """ Checks if download should actually be done
-        """
-        return (request.save_response or request.return_data) and \
-               (self.redownload or response_path is None or not os.path.exists(response_path))
+        """Checks if download should actually be done"""
+        return (request.save_response or request.return_data) and (
+            self.redownload or response_path is None or not os.path.exists(response_path)
+        )
 
     @staticmethod
     def _check_cached_request_is_matching(request, request_path):
-        """ Ensures that the cached request matches the current one. Serves as protection against hash collisions
-        """
+        """Ensures that the cached request matches the current one. Serves as protection against hash collisions"""
+        if not request_path:
+            return
+
         cached_request_info = read_data(request_path, MimeType.JSON)
         current_request_info = request.get_request_params(include_metadata=False)
         # Timestamps are allowed to differ
-        del cached_request_info['timestamp']
-        del cached_request_info['headers']
+        del cached_request_info["timestamp"]
+        del cached_request_info["headers"]
         # Saved request was jsonified
         current_request_info_json = json.loads(json.dumps(current_request_info))
 
         if cached_request_info != current_request_info_json:
             raise HashedNameCollisionException(
-                f'Request has hashed name {request.get_hashed_name()}, which matches request saved at {request_path}, '
-                f'but the requests are different. Possible hash collision'
+                f"Request has hashed name {request.get_hashed_name()}, which matches request saved at {request_path}, "
+                "but the requests are different. Possible hash collision"
             )
 
     def get_json(self, url, post_values=None, headers=None, request_type=None, **kwargs):
-        """ Download request as JSON data type
+        """Download request as JSON data type
 
         :param url: An URL from where the data will be downloaded
         :type url: str
@@ -200,19 +203,22 @@ class DownloadClient:
         if request_type is None:
             request_type = RequestType.GET if post_values is None else RequestType.POST
 
-        if request_type is RequestType.POST and 'Content-Type' not in json_headers:
-            json_headers = {
-                'Content-Type': MimeType.JSON.get_string(),
-                **json_headers
-            }
+        if request_type is RequestType.POST and "Content-Type" not in json_headers:
+            json_headers = {"Content-Type": MimeType.JSON.get_string(), **json_headers}
 
-        request = DownloadRequest(url=url, headers=json_headers, request_type=request_type, post_values=post_values,
-                                  data_type=MimeType.JSON, **kwargs)
+        request = DownloadRequest(
+            url=url,
+            headers=json_headers,
+            request_type=request_type,
+            post_values=post_values,
+            data_type=MimeType.JSON,
+            **kwargs,
+        )
 
         return self._single_download(request, decode_data=True)
 
     def get_xml(self, url, **kwargs):
-        """ Download request as XML data type
+        """Download request as XML data type
 
         :param url: url to Sentinel Hub's services or other sources from where the data is downloaded
         :type url: str
