@@ -8,20 +8,27 @@ from pytest import approx
 
 
 def get_input_folder(current_file):
-    """ Use fixtures if possible. This is meant only for test cases
-    """
-    return os.path.join(os.path.dirname(os.path.realpath(current_file)), 'TestInputs')
+    """Use fixtures if possible. This is meant only for test cases"""
+    return os.path.join(os.path.dirname(os.path.realpath(current_file)), "TestInputs")
 
 
 def get_output_folder(current_file):
-    """ Use fixtures if possible. This is meant only for test cases
-    """
-    return os.path.join(os.path.dirname(os.path.realpath(current_file)), 'TestOutputs')
+    """Use fixtures if possible. This is meant only for test cases"""
+    return os.path.join(os.path.dirname(os.path.realpath(current_file)), "TestOutputs")
 
 
-def test_numpy_data(data=None, exp_shape=None, exp_dtype=None, exp_min=None, exp_max=None, exp_mean=None,
-                    exp_median=None, exp_std=None, delta=None):
-    """ Validates basic statistics of data array
+def test_numpy_data(
+    data=None,
+    exp_shape=None,
+    exp_dtype=None,
+    exp_min=None,
+    exp_max=None,
+    exp_mean=None,
+    exp_median=None,
+    exp_std=None,
+    delta=None,
+):
+    """Validates basic statistics of data array
 
     :param data: Data array
     :type data: numpy.ndarray
@@ -47,16 +54,16 @@ def test_numpy_data(data=None, exp_shape=None, exp_dtype=None, exp_min=None, exp
     delta = delta if delta is not None else 1e-4
 
     stats_suite = {
-        'shape': (lambda array: array.shape, exp_shape),
-        'dtype': (lambda array: array.dtype, exp_dtype),
-        'min': (np.nanmin, exp_min),
-        'max': (np.nanmax, exp_max),
-        'mean': (np.nanmean, exp_mean),
-        'median': (np.nanmedian, exp_median),
-        'std': (np.nanstd, exp_std),
+        "shape": (lambda array: array.shape, exp_shape),
+        "dtype": (lambda array: array.dtype, exp_dtype),
+        "min": (np.nanmin, exp_min),
+        "max": (np.nanmax, exp_max),
+        "mean": (np.nanmean, exp_mean),
+        "median": (np.nanmedian, exp_median),
+        "std": (np.nanstd, exp_std),
     }
 
-    is_precise = {'shape', 'dtype'}
+    is_precise = {"shape", "dtype"}
 
     data_stats, exp_stats = {}, {}
     for name, (func, expected) in stats_suite.items():
@@ -64,4 +71,4 @@ def test_numpy_data(data=None, exp_shape=None, exp_dtype=None, exp_min=None, exp
             data_stats[name] = func(data)
             exp_stats[name] = expected if name in is_precise else approx(expected, rel=delta)
 
-    assert data_stats == exp_stats, 'Statistics differ from expected values'
+    assert data_stats == exp_stats, "Statistics differ from expected values"
